@@ -28,9 +28,8 @@
  * columns.
  *
  * The currently selected family can be altered with
- * he_font_selector_select_family().  The style can be selected
- * with he_font_selection_select_style().  The size can be selected
- * with he_font_selection_select_size().
+ * he_font_selector_select_family().  The size can be selected
+ * with he_font_selector_select_size().
  */
 
 #define _GNU_SOURCE     /* needed for GNU nl_langinfo_l */
@@ -80,10 +79,10 @@ struct _HeFontSelectorPrivate
   GtkWidget *preview;
 };
 
-static GObject * he_font_selector_constructor (GType                  type,
+/* static GObject * he_font_selector_constructor (GType                  type,
                                                    guint                  n_construct_properties,
-                                                   GObjectConstructParam *construct_properties);
-static void he_font_selector_finalize (GObject * object);
+                                                   GObjectConstructParam *construct_properties); */
+//static void he_font_selector_finalize (GObject * object);
 
 /* private functions */
 static GtkTreeModel *he_font_selector_create_family_model (HeFontSelector * selector);
@@ -97,13 +96,13 @@ static void he_font_selector_init (HeFontSelector * selector);
 
 static gpointer                                 parent_class = NULL;
 
-/**
-  * he_font_selector_get_type:
-  *
-  * Initializes and returns the type of a he font selector.
-  *
-  * Returns: GType of #HeFontSelector.
-  */
+/*
+ * he_font_selector_get_type:
+ *
+ * Initializes and returns the type of a he font selector.
+ *
+ * Returns: GType of #HeFontSelector.
+ */
  GType G_GNUC_CONST
  he_font_selector_get_type                    (void)
  {
@@ -114,15 +113,16 @@ static gpointer                                 parent_class = NULL;
      {
          static const GTypeInfo font_selector_info =
          {
-             sizeof (HeFontSelectorClass),
+             sizeof (HeFontSelectorClass), /* class_size */
              NULL,           /* base_init */
              NULL,           /* base_finalize */
-             (GClassInitFunc) he_font_selector_class_init,
+             (GClassInitFunc) he_font_selector_class_init, /* class_init */
              NULL,           /* class_finalize */
              NULL,           /* class_data */
-             sizeof (HeFontSelector),
+             sizeof (HeFontSelector), /* instance_size */
              0,              /* n_preallocs */
-             (GInstanceInitFunc) he_font_selector_init,
+             (GInstanceInitFunc) he_font_selector_init, /* instance_init */
+             NULL /* value_table */
          };
 
          font_selector_type = g_type_register_static (GTK_TYPE_VBOX, "HeFontSelector",
@@ -132,13 +132,13 @@ static gpointer                                 parent_class = NULL;
      return font_selector_type;
  }
 
-static void
+/* static void
 he_font_selector_set_property (GObject      *object,
                                    guint         prop_id,
                                    const GValue *value,
                                    GParamSpec   *pspec)
 {
-  HeFontSelectorPrivate *priv = HE_FONT_SELECTOR (object)->priv;
+  //HeFontSelectorPrivate *priv = HE_FONT_SELECTOR (object)->priv;
 
   switch (prop_id)
   {
@@ -153,19 +153,19 @@ he_font_selector_get_property (GObject      *object,
                                    GValue       *value,
                                    GParamSpec   *pspec)
 {
-  HeFontSelectorPrivate *priv = HE_FONT_SELECTOR (object)->priv;
+  //HeFontSelectorPrivate *priv = HE_FONT_SELECTOR (object)->priv;
 
   switch (prop_id)
   {
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
   }
-}
+} */
 
 static void
 he_font_selector_class_init (HeFontSelectorClass * class)
 {
-  //g_debug ("he_font_selector_class_init");
+  //g_warning ("he_font_selector_class_init");
   GObjectClass *gobject_class;
   GtkObjectClass *object_class;
   GtkWidgetClass *widget_class;
@@ -184,7 +184,7 @@ he_font_selector_class_init (HeFontSelectorClass * class)
 static void
 he_font_selector_init (HeFontSelector * selector)
 {
-  //g_debug ("he_font_selector_init");
+  //g_warning ("he_font_selector_init");
   selector->priv = HE_FONT_SELECTOR_GET_PRIVATE (selector);
   selector->priv->familySelector = hildon_touch_selector_new ();
   selector->priv->sizeSelector = hildon_touch_selector_new ();
@@ -192,7 +192,7 @@ he_font_selector_init (HeFontSelector * selector)
   GtkWidget *hbox = gtk_hbox_new (FALSE, 0);
   HildonTouchSelectorColumn *column = NULL;
   selector->priv->preview = hildon_entry_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
-  GtkWidget *previewLabel = gtk_label_new ("Font preview");
+  //GtkWidget *previewLabel = gtk_label_new ("Font preview");
   hildon_entry_set_text (HILDON_ENTRY (selector->priv->preview), "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz");
   gtk_widget_set_sensitive (selector->priv->preview, FALSE);
 
@@ -243,52 +243,54 @@ he_font_selector_init (HeFontSelector * selector)
   gtk_widget_set_redraw_on_allocate (GTK_WIDGET (selector), FALSE);
 }
 
-static void
+/* static void
 he_font_selector_finalize (GObject * object)
 {
-  //g_debug ("he_font_selector_finalize");
+  //g_warning ("he_font_selector_finalize");
   HeFontSelector *selector = NULL;
 
   selector = HE_FONT_SELECTOR (object);
 
   if (G_OBJECT_CLASS (parent_class)->finalize)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
-}
+} */
 
 /* ------------------------------ PRIVATE METHODS ---------------------------- */
 
 static GtkTreeModel *
 he_font_selector_create_size_model (HeFontSelector * selector)
 {
-  //g_debug ("he_font_selector_create_size_model");
-  GtkListStore *store_size = NULL;
-  gint i = 0;
-  gchar *label;
-  GtkTreeIter iter;
-//  gint font_sizes[] = { 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 54, 56, 58, 60, 62, 64, 66, 68, 70, 72 };
+    (void)selector; // Supress the compiler message about the unused parameter.
 
-  store_size = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
-  for (i = 6; i < 72; i++) {
-    label = g_strdup_printf ("%d", i);
+    //g_warning ("he_font_selector_create_size_model");
+    GtkListStore *store_size = NULL;
+    guint i = 0;
+    gchar *label;
+    GtkTreeIter iter;
+    //gint font_sizes[] = { 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32 };
 
-    gtk_list_store_append (store_size, &iter);
-    gtk_list_store_set (store_size, &iter, COLUMN_STRING, label,
-                        COLUMN_INT, i-6,
-                        -1);
-  }
-  g_free (label);
+    store_size = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
+    for (i = 6; i <= 72; i++) {
+        label = g_strdup_printf ("%d", i);
 
-  return GTK_TREE_MODEL (store_size);
+        gtk_list_store_append (store_size, &iter);
+        gtk_list_store_set (store_size, &iter, COLUMN_STRING, label,
+                            COLUMN_INT, i,
+                            -1);
+    }
+    g_free (label);
+
+    return GTK_TREE_MODEL (store_size);
 }
 
 static GtkTreeModel *
 he_font_selector_create_family_model (HeFontSelector * selector)
 {
-  //g_debug ("he_font_selector_create_family_model");
+  //g_warning ("he_font_selector_create_family_model");
   GtkTreeIter iter;
   gint i = 0;
   GtkListStore *store_family = NULL;
-  gchar *label;
+  gchar *label = NULL;
   PangoFontFamily **families;
   gint n_families;
 
@@ -312,21 +314,26 @@ he_font_selector_create_family_model (HeFontSelector * selector)
 static void
 he_font_selector_change_selector_selection (HildonTouchSelector *s, gint column, HeFontSelector *selector)
 {
-	//g_debug ("he_font_selector_change_selector_selection");
-	he_font_selector_update_preview_widget (selector);
+    (void)s; // Supress the compiler message about the unused parameter.
+    (void)column; // Supress the compiler message about the unused parameter.
+
+    //g_warning ("he_font_selector_change_selector_selection");
+    he_font_selector_update_preview_widget (selector);
 }
 
 static void
 he_font_selector_toggle_style_buttons (GtkButton *button, HeFontSelector *selector)
 {
-	//g_debug ("he_font_selector_toggle_style_buttons");
-	he_font_selector_update_preview_widget (selector);
+    (void)button; // Supress the compiler message about the unused parameter.
+
+    //g_warning ("he_font_selector_toggle_style_buttons");
+    he_font_selector_update_preview_widget (selector);
 }
 
 static void
 he_font_selector_update_preview_widget (HeFontSelector *selector)
 {
-	//g_debug ("he_font_selector_update_preview_widget");
+	//g_warning ("he_font_selector_update_preview_widget");
 	gchar *font_desc = he_font_selector_get_font (selector);
 	gtk_widget_modify_font (selector->priv->preview, pango_font_description_from_string (font_desc));
 	g_free (font_desc);
@@ -346,7 +353,7 @@ he_font_selector_update_preview_widget (HeFontSelector *selector)
 GtkWidget *
 he_font_selector_new ()
 {
-  //g_debug ("he_font_selector_new");
+  //g_warning ("he_font_selector_new");
   return g_object_new (HE_TYPE_FONT_SELECTOR, NULL);
 }
 
@@ -363,7 +370,7 @@ he_font_selector_new ()
 GtkWidget *
 he_font_selector_new_with_default_font (gchar *default_font)
 {
-  //g_debug ("he_font_selector_new_with_default_font");
+  //g_warning ("he_font_selector_new_with_default_font");
   GtkWidget *selector;
 
   selector = g_object_new (HE_TYPE_FONT_SELECTOR, NULL);
@@ -379,14 +386,15 @@ he_font_selector_new_with_default_font (gchar *default_font)
  *
  * Sets the current active font on the #HeFontSelector widget
  *
- * Since: 2.2
+ * Returns: %TRUE
  *
+ * Since: 2.2
  **/
 gboolean
 he_font_selector_set_font (HeFontSelector *selector,
                                           gchar *font_string)
 {
-	//g_debug ("he_font_selector_set_font");
+	//g_warning ("he_font_selector_set_font");
 	PangoFontDescription *font_desc = pango_font_description_from_string (font_string);
 	GtkTreeIter iter;
 	gboolean exists=FALSE;
@@ -530,8 +538,8 @@ he_font_selector_select_size (HeFontSelector * selector,
 gchar *
 he_font_selector_get_font (HeFontSelector * selector)
 {
-  //g_debug ("he_font_selector_get_font");
-  GtkTreeIter iter;
+  //g_warning ("he_font_selector_get_font");
+  //GtkTreeIter iter;
   gchar *familyString=NULL;
   gchar *styleString=NULL;
   gchar *sizeString=NULL;
