@@ -66,16 +66,24 @@ QbwLoggerVerbosity qbw_logger(QbwLoggerAction action, QbwLoggerVerbosity verbosi
 			va_end (args);
 			GTimeVal tv;
 			g_get_current_time (&tv);
-			gchar *msg1 = g_strdup_printf("[%lu.%06lu.v%d] %s\n", tv.tv_sec, tv.tv_usec, verbosity-1,msg);
+			gchar *isotime = g_time_val_to_iso8601(&tv);
+			gchar *msg1 = g_strdup_printf("[%s.v%d] %s\n", isotime, verbosity-1,msg);
 			i=fputs (msg1, logFile);
 			if (loggerVerbosity==QBW_LOGGER_VMAX-1) fflush(logFile);
 			//g_warning("*[%d]%s",i,msg1);
+			g_free(isotime);
 			g_free(msg);
 			g_free(msg1);
 		}
 		break;
 	case QBW_LOGGER_SET_VERBOSITY:
 		loggerVerbosity = verbosity;
+		if (loggerVerbosity && !logFile) {
+			g_warning ("(%p) %s(%d,%d)", NULL, G_STRFUNC, action, verbosity);
+			logFilename = g_strconcat (HOME_DIR, QUEEN_BEECON_PRIVATE_DIR, QBW_LOGFILE, NULL);
+			logFile=fopen (logFilename, "w");
+			g_free(logFilename);
+		}
 		break;
 	case QBW_LOGGER_GET_VERBOSITY:
 		return(loggerVerbosity);
