@@ -46,7 +46,7 @@ static gboolean queen_beecon_exec_animation_callback(QueenBeecon *self)
 void queen_beecon_exec_progress_animation(QueenBeecon *self, QbwProgressAnimationAction action)
 {
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) %s action=%s OnSight=%d animationInProgress=%d", self, G_STRFUNC, qbwProgressAnimationAction[action], self->priv->qbwOnSight, self->priv->animationInProgress);
-	guint i;
+	guint i,pAP;
 	gchar *progressImgFilename;
 	GdkPixbuf *pixbuf;
 	gint fx,fy,fw,fh;
@@ -70,11 +70,15 @@ void queen_beecon_exec_progress_animation(QueenBeecon *self, QbwProgressAnimatio
 		break;
 
 	case QBW_PROGRESS_ANIMATION_START:
-		if (!self->priv->progressAnimationFrames) {
-			self->priv->startupAnimation = FALSE;
-			break; // Is widget On Sight and frames needed? If no, nonsense to trigger animation
-		}
+		if (!self->priv->progressAnimationFrames) {self->priv->startupAnimation = FALSE;break;} // Is widget On Sight and frames needed? If no, nonsense to trigger animation
 		if (!self->priv->startupAnimation) if (!self->priv->qbwOnSight) break; // Is widget On Sight and frames needed? If no, nonsense to trigger animation
+		if (!self->priv->widgetVisible) break; // Is widget On Sight and frames needed? If no, nonsense to trigger animation
+		if (self->priv->progressAnimationPos/9 == 1) {
+			gtk_widget_hide (GTK_WIDGET(self->priv->cmdTitle_lb));
+			gtk_widget_hide (GTK_WIDGET(self->priv->cmdTitle_img));
+			gtk_widget_hide (GTK_WIDGET(self->priv->cmdResult_lb));
+			gtk_widget_hide (GTK_WIDGET(self->priv->cmdResult_img));
+		}
 		self->priv->startupAnimation = FALSE;
 		self->priv->animationInProgress = TRUE;
 		self->priv->xx=self->priv->clickX;
@@ -129,8 +133,9 @@ void queen_beecon_exec_progress_animation(QueenBeecon *self, QbwProgressAnimatio
 		fh=gdk_pixbuf_get_width (pixbuf);
 		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_img), fw, fh);
 		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_fixed), fw, fh);
-		fx=(self->priv->progressAnimationPos)%3==0?0:(self->priv->progressAnimationPos)%3==1?(gint)self->priv->widWidth/2-fw/2:(gint)self->priv->widWidth-fw;
-		fy=(self->priv->progressAnimationPos)/3==0?0:(self->priv->progressAnimationPos)/3==1?(gint)self->priv->widHeight/2-fh/2:(gint)self->priv->widHeight-fh;
+		pAP = self->priv->progressAnimationPos%9;
+		fx=pAP%3==0?0:pAP%3==1?(gint)self->priv->widWidth/2-fw/2:(gint)self->priv->widWidth-fw;
+		fy=pAP/3==0?0:pAP/3==1?(gint)self->priv->widHeight/2-fh/2:(gint)self->priv->widHeight-fh;
 		if (self->priv->progressAnimationAtClickXY && self->priv->clickX!=-1 && self->priv->clickY!=-1 ) {
 			fx=self->priv->xx-fw/2;
 			fy=self->priv->yy-fh/2;
@@ -153,8 +158,9 @@ void queen_beecon_exec_progress_animation(QueenBeecon *self, QbwProgressAnimatio
 		fh=gdk_pixbuf_get_width (pixbuf);
 		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_img), fw, fh);
 		gtk_widget_set_size_request(GTK_WIDGET(self->priv->beeExecuting_fixed), fw, fh);
-		fx=(self->priv->progressAnimationPos)%3==0?0:(self->priv->progressAnimationPos)%3==1?(gint)self->priv->widWidth/2-fw/2:(gint)self->priv->widWidth-fw;
-		fy=(self->priv->progressAnimationPos)/3==0?0:(self->priv->progressAnimationPos)/3==1?(gint)self->priv->widHeight/2-fh/2:(gint)self->priv->widHeight-fh;
+		pAP = self->priv->progressAnimationPos%9;
+		fx=pAP%3==0?0:pAP%3==1?(gint)self->priv->widWidth/2-fw/2:(gint)self->priv->widWidth-fw;
+		fy=pAP/3==0?0:pAP/3==1?(gint)self->priv->widHeight/2-fh/2:(gint)self->priv->widHeight-fh;
 		if (self->priv->progressAnimationAtClickXY && self->priv->clickX!=-1 && self->priv->clickY!=-1 ) {
 			fx=self->priv->xx-fw/2;
 			fy=self->priv->yy-fh/2;
@@ -171,6 +177,10 @@ void queen_beecon_exec_progress_animation(QueenBeecon *self, QbwProgressAnimatio
 		if (self->priv->animationInProgress) {
 			self->priv->animationInProgress = FALSE;
 			gtk_widget_hide(self->priv->beeExecuting_img);
+			if (self->priv->cmdVisibilityPosition    && self->priv->widgetVisible) gtk_widget_show (GTK_WIDGET(self->priv->cmdTitle_lb));
+			if (self->priv->cmdImgVisibilityPosition && self->priv->widgetVisible) gtk_widget_show (GTK_WIDGET(self->priv->cmdTitle_img));
+			if (self->priv->resVisibilityPosition    && self->priv->widgetVisible) gtk_widget_show (GTK_WIDGET(self->priv->cmdResult_lb));
+			if (self->priv->resImgVisibilityPosition && self->priv->widgetVisible) gtk_widget_show (GTK_WIDGET(self->priv->cmdResult_img));
 		}
 		break;
 
