@@ -151,8 +151,8 @@ needInstanceSettings:
 		self->priv->widgetType = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "widgetType", 0);//0=Beecon
 		self->priv->widgetVisible = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "widgetVisible", 1);//0=Hidden; 1=Visible
 		self->priv->operationalStatus = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "operationalStatus", 0);//0=Maximized/Enabled
-		self->priv->hideCanvas = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "hideCanvas", FALSE);//FALSE=Show Canvas by default
-		self->priv->hideClickCanvas = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "hideClickCanvas", FALSE);//FALSE=Show Canvas on click by default
+		self->priv->hideCanvas = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "hideCanvas", TRUE);//TRUE=Hide Canvas by default
+		self->priv->hideClickCanvas = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "hideClickCanvas", TRUE);//TRUE=Hide Canvas on click by default
 		self->priv->snippetBgRGB = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "snippetBgRGB", 0);//0=Black
 
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) self->priv->snippetExtBgRGB = %p", self, self->priv->snippetExtBgRGB);
@@ -225,8 +225,8 @@ needInstanceSettings:
 		self->priv->beecon_idxge2_ExtBgRGB = g_strdup(queen_beecon_g_key_file_get_string (keyFile, sourceGroup, "beecon_idxge2_ExtBgRGB", p_colors[self->priv->beecon_idxge2_BgRGB].colorRGB));//No Image filename
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) self->priv->beecon_idxge2_ExtBgRGB = %p", self, self->priv->beecon_idxge2_ExtBgRGB);
 
-		self->priv->widWidth = queen_beecon_g_key_file_get_double (keyFile, sourceGroup, "widWidth", 130.0);//130px
-		self->priv->widHeight = queen_beecon_g_key_file_get_double (keyFile, sourceGroup, "widHeight", 115.0);//115px
+		self->priv->widWidth = queen_beecon_g_key_file_get_double (keyFile, sourceGroup, "widWidth", 150.0);//
+		self->priv->widHeight = queen_beecon_g_key_file_get_double (keyFile, sourceGroup, "widHeight", 130.0);//
 
 //----------
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) self->priv->cmdImgFilename = %p", self, self->priv->cmdImgFilename);
@@ -274,11 +274,12 @@ needInstanceSettings:
 
 		self->priv->resTextAngle = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resTextAngle", 0); //Horizontal, Left to Right
 		self->priv->resVisibilityPosition = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resVisibilityPosition", 8);//center-center
-		self->priv->resImgVisibilityPosition = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resImgVisibilityPosition", 9);//bottom-center
+		self->priv->resImgVisibilityPosition = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resImgVisibilityPosition", 3);//bottom-right
 		self->priv->resJustify = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resJustify", 0);//0=left
+		self->priv->resWrapLongLines = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "resWrapLongLines", FALSE);// Wrap Long Lines?
 
-		self->priv->resFontName = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resFontName", 2);//
-		self->priv->resFontSize = queen_beecon_g_key_file_get_double (keyFile, sourceGroup, "resFontSize", 12);//12
+		self->priv->resFontName = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resFontName", 16);//
+		self->priv->resFontSize = queen_beecon_g_key_file_get_double (keyFile, sourceGroup, "resFontSize", 10);//12
 
 		gchar *resFontTtl = g_strdup_printf("%s %s %ld", p_fonts[self->priv->resFontName/4], self->priv->resFontName%4?p_fonts_types[self->priv->resFontName%4]:"", (long) self->priv->resFontSize);//AP1
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) Result Font: %s",self, resFontTtl);
@@ -317,14 +318,19 @@ needInstanceSettings:
 		//BEGIN update policy
 		self->priv->updOnStartup = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "updOnStartup", FALSE);//FALSE= Do NOT Update when widget launched
 		self->priv->updOnClick = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "updOnClick", TRUE);//TRUE= Update when clicked
+		self->priv->multiClick = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "multiClick", FALSE);//FALSE= Multiclick not supported
 		self->priv->updOnDesktop = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "updOnDesktop", FALSE);//TRUE= Do NOT Update when widget's desktop switched
 		self->priv->updOnSight = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "updOnSight", FALSE);//FALSE= Update even if out of sight
+		self->priv->updOnOrientation = queen_beecon_g_key_file_get_boolean (keyFile, sourceGroup, "updOnOrientation", FALSE);//FALSE= Don't sense Orientation changes
 		self->priv->delayIndex = (guint) queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "delayIndex", 0);//0=Assume no timer event
 		if (self->priv->delayIndex) self->priv->delaySeconds = GetSeconds(self->priv->delayIndex);
 		self->priv->customIntervalSecs = (guint) queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "customIntervalSecs", 0);//0=Assume no timer event
 		if (self->priv->delayIndex==9) self->priv->delaySeconds = self->priv->customIntervalSecs;
 		self->priv->updNeworkPolicy = (guint) queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "updNeworkPolicy", NETWORK__UNRELATED);
-//---------- DBUS parameters
+
+		self->priv->GPSsettings = (guint) queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "GPSsettings", 0x0000);//0=Assume GPS Disabled, USER_SELECTED method, DEFAULT interval
+
+		//---------- DBUS parameters
 		self->priv->updOnDBUS = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "updOnDBUS", 0);//FALSE= Do NOT Update on DBUS events
 		self->priv->updOnDBUSBus = (guint) queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "updOnDBUSBus", 0); //Defaults to System DBUS
 
@@ -446,6 +452,7 @@ void queen_beecon_write_settings (QueenBeecon *self, gboolean needInstanceSettin
 		g_key_file_set_string (keyFile, self->priv->widgetID, "resExtFont", self->priv->resExtFont);//AP3
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "resFontName", self->priv->resFontName);//AP1
 		g_key_file_set_double (keyFile, self->priv->widgetID, "resFontSize", self->priv->resFontSize);//AP1
+		g_key_file_set_boolean (keyFile, self->priv->widgetID, "resWrapLongLines", self->priv->resWrapLongLines);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "progressAnimationFrames", self->priv->progressAnimationFrames);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "progressAnimationTimer", self->priv->progressAnimationTimer);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "progressAnimationPos", self->priv->progressAnimationPos);
@@ -453,11 +460,14 @@ void queen_beecon_write_settings (QueenBeecon *self, gboolean needInstanceSettin
 		g_key_file_set_string (keyFile, self->priv->widgetID, "progressAnimationBasename", self->priv->progressAnimationBasename);
 		g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnStartup", self->priv->updOnStartup);
 		g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnClick", self->priv->updOnClick);
+		g_key_file_set_boolean (keyFile, self->priv->widgetID, "multiClick", self->priv->multiClick);
 		g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnDesktop", self->priv->updOnDesktop);
 		g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnSight", self->priv->updOnSight);
+		g_key_file_set_boolean (keyFile, self->priv->widgetID, "updOnOrientation", self->priv->updOnOrientation);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "delayIndex", self->priv->delayIndex);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "customIntervalSecs", self->priv->customIntervalSecs);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "updNeworkPolicy", self->priv->updNeworkPolicy);
+		g_key_file_set_integer (keyFile, self->priv->widgetID, "GPSsettings", self->priv->GPSsettings);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "updOnDBUS", self->priv->updOnDBUS);
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "updOnDBUSBus", self->priv->updOnDBUSBus);//AP3
 		g_key_file_set_string  (keyFile, self->priv->widgetID, "updOnDBUSMatchRule", self->priv->updOnDBUSMatchRule);//AP3
@@ -545,7 +555,8 @@ gboolean write_settings_have_key(const gchar *group_name, const gchar *key, void
 
 	if (fileExists) {
 		if (!g_key_file_has_key(keyFile, group_name, key, &error)) {
-			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) g_key_file_has_key failed: %s\n", NULL, error->message);
+			//qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) g_key_file_has_key failed: %s", NULL, error->message);
+			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) g_key_file_has_key failed", NULL);
 			g_clear_error (&error);
 			RC = FALSE; // If key is not present in settings file then returns FALSE
 		} else {
